==> eiffelstudio-18.01.10.1424.tar: F_code/C3/co143.c <==
/*
 * Code for class CODE_SETS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co143.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CODE_SETS}.two_byte_code_pages */
static EIF_REFERENCE F172_2173_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("two_byte_code_pages", 171, Current, 0, 0, 2298);
	RTGC;
	RTOSP (2173);
#define Result RTOSR(2173)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {808,1046,1046,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 808, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F809_7402(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("UCS-2",5,1130177330);
	tr2 = RTMS_EX_H("ucs-2",5,1669391154);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(3);
	tr1 = RTMS_EX_H("ISO-10646-UCS-2",15,137660722);
	tr2 = RTMS_EX_H("iso-10646-ucs-2",15,932466994);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(4);
	tr1 = RTMS_EX_H("csUnicode",9,1140938597);
	tr2 = RTMS_EX_H("csunicode",9,67227493);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(5);
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(6);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(7);
	tr1 = RTMS_EX_H("UNICODE-1-1",11,1407647281);
	tr2 = RTMS_EX_H("unicode-1-1",11,366474289);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(8);
	tr1 = RTMS_EX_H("csUnicode11",11,1599950641);
	tr2 = RTMS_EX_H("csunicode11",11,1339907633);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(9);
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(10);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(11);
	tr1 = RTMS_EX_H("UTF-16",6,1345128758);
	tr2 = RTMS_EX_H("utf-16",6,1945159990);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(12);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(13);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(14);
	tr1 = RTMS_EX_H("UCS-2-INTERNAL",14,834453068);
	tr2 = RTMS_EX_H("ucs-2-internal",14,1377880940);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(15);
	tr1 = RTMS_EX_H("UCS-2-SWAPPED",13,297507908);
	tr2 = RTMS_EX_H("ucs-2-swapped",13,861666404);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(16);
	tr1 = RTMS_EX_H("JAVA",4,1245795905);
	tr2 = RTMS_EX_H("java",4,1784772193);
	F809_7447(RTCW(Result), tr1, tr2);
	RTOSE (2173);
	RTHOOK(17);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F172_2173 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2173,F172_2173_body,(Current));
}

/* {CODE_SETS}.four_byte_code_pages */
static EIF_REFERENCE F172_2174_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("four_byte_code_pages", 171, Current, 0, 0, 2299);
	RTGC;
	RTOSP (2174);
#define Result RTOSR(2174)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {808,1046,1046,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 808, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F809_7402(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("UCS-4",5,1130177332);
	tr2 = RTMS_EX_H("ucs-4",5,1669391156);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(3);
	tr1 = RTMS_EX_H("ISO-10646-UCS-4",15,137660724);
	tr2 = RTMS_EX_H("iso-10646-ucs-4",15,932466996);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(4);
	tr1 = RTMS_EX_H("csUCS4",6,1626000692);
	tr2 = RTMS_EX_H("csucs4",6,17497140);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(5);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(6);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(7);
	tr1 = RTMS_EX_H("UTF-32",6,1345129266);
	tr2 = RTMS_EX_H("utf-32",6,1945160498);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(8);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(9);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(10);
	tr1 = RTMS_EX_H("UCS-4-INTERNAL",14,968724556);
	tr2 = RTMS_EX_H("ucs-4-internal",14,1512152428);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(11);
	tr1 = RTMS_EX_H("UCS-4-SWAPPED",13,415472708);
	tr2 = RTMS_EX_H("ucs-4-swapped",13,979631204);
	F809_7447(RTCW(Result), tr1, tr2);
	RTOSE (2174);
	RTHOOK(12);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F172_2174 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2174,F172_2174_body,(Current));
}

/* {CODE_SETS}.little_endian_code_pages */
static EIF_REFERENCE F172_2175_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("little_endian_code_pages", 171, Current, 0, 0, 2300);
	RTGC;
	RTOSP (2175);
#define Result RTOSR(2175)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {808,1046,1046,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 808, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F809_7402(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(3);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(4);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(5);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(6);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F809_7447(RTCW(Result), tr1, tr2);
	RTOSE (2175);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F172_2175 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2175,F172_2175_body,(Current));
}

/* {CODE_SETS}.big_endian_code_pages */
static EIF_REFERENCE F172_2176_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("big_endian_code_pages", 171, Current, 0, 0, 2301);
	RTGC;
	RTOSP (2176);
#define Result RTOSR(2176)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {808,1046,1046,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 808, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F809_7402(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(3);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(4);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(5);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F809_7447(RTCW(Result), tr1, tr2);
	RTHOOK(6);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F809_7447(RTCW(Result), tr1, tr2);
	RTOSE (2176);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F172_2176 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2176,F172_2176_body,(Current));
}

void EIF_Minit143 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C3/co143.c <==
/*
 * Code for class CODE_SETS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co143.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CODE_SETS}.two_byte_code_pages */
static EIF_REFERENCE F166_2619_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(577)

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOTP;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,906,0xFF01,1132,0xFF01,1132,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 906, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F907_8107(RTCW(tr1), ((EIF_INTEGER_32) 20L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2",5,1130177330);
	tr2 = RTMS_EX_H("ucs-2",5,1669391154);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-2",15,137660722);
	tr2 = RTMS_EX_H("iso-10646-ucs-2",15,932466994);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode",9,1140938597);
	tr2 = RTMS_EX_H("csunicode",9,67227493);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODE-1-1",11,1407647281);
	tr2 = RTMS_EX_H("unicode-1-1",11,366474289);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUnicode11",11,1599950641);
	tr2 = RTMS_EX_H("csunicode11",11,1339907633);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16",6,1345128758);
	tr2 = RTMS_EX_H("utf-16",6,1945159990);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-INTERNAL",14,834453068);
	tr2 = RTMS_EX_H("ucs-2-internal",14,1377880940);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-2-SWAPPED",13,297507908);
	tr2 = RTMS_EX_H("ucs-2-swapped",13,861666404);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("JAVA",4,1245795905);
	tr2 = RTMS_EX_H("java",4,1784772193);
	F907_8153(RTCW(Result), tr1, tr2);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F166_2619 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(577,F166_2619_body,(Current));
}

/* {CODE_SETS}.four_byte_code_pages */
static EIF_REFERENCE F166_2620_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(578)

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOTP;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,906,0xFF01,1132,0xFF01,1132,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 906, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F907_8107(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-4",5,1130177332);
	tr2 = RTMS_EX_H("ucs-4",5,1669391156);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("ISO-10646-UCS-4",15,137660724);
	tr2 = RTMS_EX_H("iso-10646-ucs-4",15,932466996);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("csUCS4",6,1626000692);
	tr2 = RTMS_EX_H("csucs4",6,17497140);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32",6,1345129266);
	tr2 = RTMS_EX_H("utf-32",6,1945160498);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-INTERNAL",14,968724556);
	tr2 = RTMS_EX_H("ucs-4-internal",14,1512152428);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4-SWAPPED",13,415472708);
	tr2 = RTMS_EX_H("ucs-4-swapped",13,979631204);
	F907_8153(RTCW(Result), tr1, tr2);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F166_2620 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(578,F166_2620_body,(Current));
}

/* {CODE_SETS}.little_endian_code_pages */
static EIF_REFERENCE F166_2621_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(580)

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOTP;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,906,0xFF01,1132,0xFF01,1132,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 906, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F907_8107(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2LE",7,722940485);
	tr2 = RTMS_EX_H("ucs-2le",7,1859877733);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODELITTLE",13,852373061);
	tr2 = RTMS_EX_H("unicodelittle",13,1164725349);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16LE",8,312185413);
	tr2 = RTMS_EX_H("utf-16le",8,1456249701);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4LE",7,723071557);
	tr2 = RTMS_EX_H("ucs-4le",7,1860008805);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32LE",8,345477701);
	tr2 = RTMS_EX_H("utf-32le",8,1489541989);
	F907_8153(RTCW(Result), tr1, tr2);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F166_2621 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(580,F166_2621_body,(Current));
}

/* {CODE_SETS}.big_endian_code_pages */
static EIF_REFERENCE F166_2622_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(579)

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOTP;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,906,0xFF01,1132,0xFF01,1132,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 906, _OBJSIZ_7_3_0_7_0_0_0_0_);
	}
	F907_8107(RTCW(tr1), ((EIF_INTEGER_32) 5L));
	Result = (EIF_REFERENCE) tr1;
	tr1 = RTMS_EX_H("UCS-2BE",7,722937925);
	tr2 = RTMS_EX_H("ucs-2be",7,1859875173);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UNICODEBIG",10,266927431);
	tr2 = RTMS_EX_H("unicodebig",10,1691026535);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-16BE",8,312182853);
	tr2 = RTMS_EX_H("utf-16be",8,1456247141);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UCS-4BE",7,723068997);
	tr2 = RTMS_EX_H("ucs-4be",7,1860006245);
	F907_8153(RTCW(Result), tr1, tr2);
	tr1 = RTMS_EX_H("UTF-32BE",8,345475141);
	tr2 = RTMS_EX_H("utf-32be",8,1489539429);
	F907_8153(RTCW(Result), tr1, tr2);
	RTOTE;
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F166_2622 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(579,F166_2622_body,(Current));
}

void EIF_Minit143 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
